import utils
from stores.mysql_data_store import MysqlDataStore


class DataClean:
    _store = None

    def __init__(self):
        self._clean_day = utils.get_config_int("clean.day", 30)
        self._clean_attach_day = utils.get_config_int("clean.attach", self._clean_day)
        self._clean_log_day = utils.get_config_int("clean.log", self._clean_day)
        self._clean_collect_data_day = utils.get_config_int(
            "clean.collect_data", self._clean_day
        )
        self._clean_process_data_day = utils.get_config_int(
            "clean.process_data", self._clean_day
        )
        self._clean_process_result_data_day = utils.get_config_int(
            "clean.process_result_data", self._clean_day
        )
        if self._clean_process_result_data_day < 45:
            self._clean_process_result_data_day = 45
        self._store = MysqlDataStore()

    def clean(self):
        try:
            utils.get_logger().info("开始 清除历史文件数据")
            self._clean_attach()
            self._clean_log()
            self._clean_collect_data()
            self._clean_process_data()
            self._clean_process_result_data()
            utils.get_logger().info("清除历史文件数据 完成")
        except Exception as e:
            utils.get_logger().error(e)

    def _clean_attach(self):
        if self._clean_attach_day == 0:
            utils.get_logger().info("跳过 清除历史附件数据")
            return
        utils.get_logger().info("开始 清除历史附件数据")
        utils.clean_attach_file(self._clean_attach_day)
        utils.get_logger().info("清除历史附件数据 完成")

    def _clean_log(self):
        if self._clean_log_day == 0:
            utils.get_logger().info("跳过 清除历史日志数据")
            return
        utils.get_logger().info("开始 清除历史日志数据")
        utils.clean_log_file(self._clean_log_day)
        utils.get_logger().info("清除历史日志数据 完成")

    def _clean_collect_data(self):
        if self._clean_collect_data_day == 0:
            utils.get_logger().info("跳过 清除历史采集数据")
            return
        utils.get_logger().info("开始 清除历史采集数据")
        date = self._get_before_date(self._clean_collect_data_day)
        self._store.delete_collect_data_before_date(date)
        utils.get_logger().info("清除历史采集数据 完成")

    def _clean_process_data(self):
        if self._clean_process_data_day == 0:
            utils.get_logger().info("跳过 清除历史处理数据[招标]")
            return
        utils.get_logger().info("开始 清除历史处理数据[招标]")
        date = self._get_before_date(self._clean_process_data_day)
        self._store.delete_process_data_before_date(date)
        utils.get_logger().info("清除历史处理数据[招标] 完成")

    def _clean_process_result_data(self):
        if self._clean_process_result_data_day == 0:
            utils.get_logger().info("跳过 清除历史处理数据[中标]")
            return
        utils.get_logger().info("开始 清除历史处理数据[中标]")
        date = self._get_before_date(self._clean_process_data_day)
        self._store.delete_process_result_data_before_date(date)
        utils.get_logger().info("清除历史处理数据[中标] 完成")

    @staticmethod
    def _get_before_date(day: int) -> str:
        from datetime import datetime, timedelta

        return (datetime.now() - timedelta(days=day)).strftime("%Y-%m-%d")
